AdaptiveWidgets class
Entry point for the package's platform-adaptive dialogs, sheets, and pickers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildRefreshableScrollView(
BuildContext context, {Key? key, Widget? header, required List< Widget> slivers, ScrollController? controller, Future<void> onRefresh()?, Clip clipBehavior = Clip.hardEdge, ScrollPhysics? physics, bool reverse = false, ScrollBehavior? scrollBehavior, bool shrinkWrap = false, Color? color, Color? refreshControlBackgroundColor, Color? refreshIndicatorBackgroundColor, EdgeInsets padding = EdgeInsets.zero}) → Widget - Constructs a platform-specific refreshable scroll view.
-
showBottomActionSheet<
T> (BuildContext context, {required List< AdaptiveBottomSheetButtonBuilder> actionButtons, bool dismissible = true, Brightness? brightness, Widget? title, Widget? message}) → Future<T?> - Shows an adaptive bottom action sheet for the current platform.
-
showDatePicker(
BuildContext context, {DateTime? minimumDate, DateTime? maximumDate, DateTime? initialDate, Brightness? brightness, bool dismissible = true, }) → Future< DateTime?> - Shows an adaptive date picker and keeps the initial value within range.
-
showDialog<
T> (BuildContext context, {String? title, String? content, required List< AdaptiveDialogButtonBuilder> actionButtons, bool dismissible = true, Brightness? brightness}) → Future<T?> - Shows an adaptive alert dialog for the current platform.
-
showTimePicker(
BuildContext context, {DateTime? initialTime, bool dismissible = true, Brightness? brightness, bool alwaysUse24HourFormat = true}) → Future< DateTime?> - Shows an adaptive time picker for the current platform.