AdaptiveBottomActionSheetButton class abstract

Builds a platform-specific action widget for an adaptive bottom action sheet.

Constructors

AdaptiveBottomActionSheetButton(TargetPlatform platform)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, {required Widget label, void onPressed(BuildContext context)?, required bool isDefaultAction, required bool isDestructiveAction, required bool isCancelAction}) Widget
Builds a tappable action widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited